@@ -6,7 +6,7 @@ use Config;
 use Module::Build;
 our @ISA = qw(Module::Build);
 
-our $VERSION = "0.04";
+our $VERSION = "0.05";
 
 __PACKAGE__->add_property( 'ppport_h_path'   => undef );
 __PACKAGE__->add_property( 'xshelper_h_path' => undef );
@@ -360,7 +360,7 @@ Use in your Build.PL
         dist_author          => 'Your Name <yourname@example.com>',
         dist_version_from    => 'lib/Your/XS/Module',
         generate_ppport_h    => 'lib/Your/XS/ppport.h',
-        generate_xs_helper_h => 'lib/Your/XS/xshelper.h',
+        generate_xshelper_h  => 'lib/Your/XS/xshelper.h',
         needs_compiler_c99   => 1,
     );
     
@@ -378,7 +378,7 @@ Use in custom builder module.
         my $self = $class->SUPER::new(
             %args,
             generate_ppport_h    => 'lib/Your/XS/ppport.h',
-            generate_xs_helper_h => 'lib/Your/XS/xshelper.h',
+            generate_xshelper_h  => 'lib/Your/XS/xshelper.h',
             needs_compiler_c99   => 1,
         );
         return $self;
